<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt:n tiedostopakkaaja&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Yksinkertainen ja työpöytä-riippumaton tiedostopakkaaja Qt:eelle</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Tekijät</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Ohjelmointi:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt:n tiedostopakkaaja on johdannettu seuraavista ohjelmista:
* MATE-työpöydän Engrampa
* Gnome-työpöydän Tiedostokäärin (File Roller)
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Arkistotyyppiä ei tueta.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 tiedostoa (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Kaikki tuetut tyypit</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Komennon suoritus epäonnistui.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Komentoa ei löydy.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Komento päättyi epänormaalisti.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Salasana vaaditaan.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Arkiston osaa ei löydy.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Kelvoton merkistö.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Tiedostotyyppiä ei tueta.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Tapahtui tuntemattomia virheitä.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Osien koko jaettaessa</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Salaa tiedostonimet</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Pura</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>Pura &amp;kaikki</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Pura &amp;valitut</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Säilytä polut purettaessa</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Korvaa tiedostot</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Älä pura vanhempia tiedostoja</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="12"/>
        <source>All files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>File Archiver</source>
        <translation>Tiedostopakkaaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Suodata tiedostot...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>&amp;Kuvakekoko</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Main Toolbar</source>
        <translation>Päätyökalurivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>&amp;New</source>
        <translation>&amp;Uusi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>&amp;Open</source>
        <translation>&amp;Avaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="213"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Save &amp;As</source>
        <translation>Tallenna &amp;nimellä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Vaihto+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Extract</source>
        <translation>&amp;Pura</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;Test</source>
        <translation>E&amp;heystarkistus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>&amp;Properties</source>
        <translation>&amp;Ominaisuudet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>&amp;Close</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Leikkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>&amp;Paste</source>
        <translation>L&amp;iitä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>&amp;Rename</source>
        <translation>&amp;Uudelleennimeä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="317"/>
        <source>&amp;Select All</source>
        <translation>&amp;Valitse kaikki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="328"/>
        <source>&amp;Find</source>
        <translation>&amp;Haku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="442"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>&amp;Add Files</source>
        <translation>Lisää &amp;tiedostoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Add F&amp;older</source>
        <translation>Lisää k&amp;ansio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Pass&amp;word</source>
        <translation>&amp;Salasana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="357"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Työkalurivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>&amp;Statusbar</source>
        <translation>T&amp;ilarivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Hakemistopuu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>S&amp;how as Folder</source>
        <translation>&amp;Näytä kansiona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Vaihto+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Show &amp;All Files</source>
        <translation>N&amp;äytä kaikki tiedostot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Vaihto+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>St&amp;op</source>
        <translation>&amp;Pysäytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>&amp;Reload</source>
        <translation>Päi&amp;vitä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="424"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>Filename &amp;Encoding</source>
        <translation>Tiedostonimien k&amp;oodaus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Näytä valitut kohteet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>&amp;Filter</source>
        <translation>&amp;Suodata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>&amp;Expand</source>
        <translation>&amp;Laajenna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Vaihto+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Vaihto+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>&amp;Collapse</source>
        <translation>S&amp;upista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>16 px</source>
        <translation>16 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>24 px</source>
        <translation>24 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>32 px</source>
        <translation>32 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>48 px</source>
        <translation>48 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <location filename="../mainwindow.cpp" line="395"/>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>All files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Add only if &amp;newer</source>
        <translation>&amp;Lisää vain, jos uudempi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Haluatko varmasti poistaa valitut tiedostot?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source>Version: %1</source>
        <translation>Versio: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="942"/>
        <source>Success</source>
        <translation>Onnistui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="942"/>
        <source>No errors have been found.</source>
        <translation>Virheitä ei löydetty.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <location filename="../mainwindow.cpp" line="977"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>N/A</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1009"/>
        <source>Uncompressed Size:</source>
        <translation>Pakkaamaton koko:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1011"/>
        <source>Compression Ratio:</source>
        <translation>Pakkaussuhde:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>File name</source>
        <translation>Tiedostonimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1067"/>
        <source>File Type</source>
        <translation>Tiedostotyyppi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>File Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Modified</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1070"/>
        <source>Encrypted</source>
        <translation>Salattu</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1096"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n tiedosto</numerusform>
            <numerusform>%n tiedostoa</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Salaa tiedostonimet</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Näytä salasana</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Huomautus:&lt;/b&gt; salasanaa käytetään salaamaan lisäämäsi tiedostot ja purkamaan salauksen tiedostoja purettaessa.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Tilanne</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7-Zip (.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>7z-pakattu tar (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace (.ace)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar (.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar (.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj (.arj)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>bzip2-pakattu tar (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>bzip-pakattu tar (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet (.cab)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar-arkistoitu sarjakuvakirja (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip-arkistoitu sarjakuvakirja (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>gzip-pakattu tar (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>Ear (.ear)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Itsepurkautuva zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar (.jar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha (.lzh)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip (.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>lrzip-pakattu tar (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>lzip-pakattu tar (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>lzma-pakattu tar (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>lzop-pakattu tar (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Windows Imaging Format (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>Rar (.rar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Pakkaamaton tar (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>compress-pakattu tar (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War (.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz (.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>xz-pakattu tar (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>zstd-pakattu tar (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo (.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip (.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Lisätään tiedostoa: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>Puretaan tiedostoa: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation>%d %B %Y, %H:%M</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Poistetaan tiedostoa: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Poistetaan tiedostoja arkistosta</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Uudelleenpakataan arkistoa</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Puretaan arkistoa</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Tiedostoa ei ole olemassa.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Arkistotyyppiä ei tueta.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Arkistoa ei ole olemassa</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Riittämättömät käyttöoikeudet.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Arkistotyyppiä ei voi muokata</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Arkistoa ei voi lisätä itseensä.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Arkiston osaa ei ole olemassa: %s</translation>
    </message>
</context>
</TS>
